# Changelog

## v1.0 (2012-06-01)

* Stabilizing the Code
* Also can convert MP4 -> MKV
* Moved to MIT license


## v0.1 (2012-03-07)

* Very simple way of handling subtitles.
* Take all the AVI files of a list of directories.
* Or take all the files passed by the command line.
* Verbose mode with a lot of information.
* Created the setuptools script.
* Created the documentation.
